package Crypt::OpenSSL3::X509::VerifyResult;
$Crypt::OpenSSL3::X509::VerifyResult::VERSION = '0.002';
use strict;
use warnings;

use Crypt::OpenSSL3;

1;

# ABSTRACT: The result of an X509 verification

__END__

=pod

=encoding UTF-8

=head1 NAME

Crypt::OpenSSL3::X509::VerifyResult - The result of an X509 verification

=head1 VERSION

version 0.002

=head1 METHODS

=head2 error_code

=head2 error_string

=head2 ok

=head1 AUTHOR

Leon Timmermans <fawaka@gmail.com>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2025 by Leon Timmermans.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
